/*
 * HotlinkingFilterTest.java
 * 
 * Created 17.12.2005.
 * 
 * Copyright (c) 2005 Johann Burkard (<mailto:jb@eaio.com>)
 * <http://eaio.com>
 * 
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
 * to deal in the Software without restriction, including without limitation
 * the rights to use, copy, modify, merge, publish, distribute, sublicense,
 * and/or sell copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following conditions:
 * 
 * The above copyright notice and this permission notice shall be included
 * in all copies or substantial portions of the Software.
 * 
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
 * OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
 * MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN
 * NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM,
 * DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR
 * OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE
 * USE OR OTHER DEALINGS IN THE SOFTWARE.
 * 
 */
package com.eaio.j2ee.filter;

import java.io.IOException;
import java.util.Enumeration;
import java.util.Vector;

import javax.servlet.FilterChain;
import javax.servlet.ServletException;
import javax.servlet.ServletRequest;
import javax.servlet.ServletResponse;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import com.eaio.j2ee.MockFilterChain;
import com.eaio.j2ee.MockFilterConfig;
import com.eaio.j2ee.MockHttpServletRequest;
import com.eaio.j2ee.MockHttpServletResponse;
import com.eaio.util.junit.AbstractTestCase;

/**
 *
 * @author <a href="mailto:jb@eaio.com">Johann Burkard</a>
 * @version $Id$
 */
public class HotlinkingFilterTest extends AbstractTestCase {

    public static void main(String[] args) {
        junit.awtui.TestRunner.run(HotlinkingFilterTest.class);
    }

    protected HotlinkingFilter instance;

    /*
     * @see AbstractTestCase#setUp()
     */
    protected void setUp() throws Exception {
        super.setUp();

        final Vector params = new Vector();
        params.add("redirect");
        params.add("referer_1");
        params.add("referer_2");
        params.add("referer_3");
        params.add("referer_666");

        instance = new HotlinkingFilter();
        instance.setFilterConfig(new MockFilterConfig() {

            /**
             * @see com.eaio.j2ee.MockFilterConfig#getInitParameter(java.lang.String)
             */
            public String getInitParameter(String arg0) {
                if ("redirect".equals(arg0)) {
                    return "http://kalifornia.com";
                }
                else if ("referer_1".equals(arg0)) {
                    return "127.0.0.1";
                }
                else if ("referer_2".equals(arg0)) {
                    return "blorb.com";
                }
                else if ("referer_3".equals(arg0)) {
                    return "blubbix.com";
                }
                else if ("referer_666".equals(arg0)) {
                    return "/blorb/blob/bla/blubbix";
                }
                return super.getInitParameter(arg0);
            }

            /**
             * @see com.eaio.j2ee.MockFilterConfig#getInitParameterNames()
             */
            public Enumeration getInitParameterNames() {
                return params.elements();
            }

        });

    }

    /*
     * @see TestCase#tearDown()
     */
    protected void tearDown() throws Exception {
        instance.destroy();
        super.tearDown();
    }

    /*
     * Test method for 'com.eaio.j2ee.filter.HotlinkingFilter.doFilter(ServletRequest, ServletResponse, FilterChain)'
     */
    public void testDoFilter() {
        HttpServletRequest request;
        HttpServletResponse response;
        FilterChain chain;
        try {
            instance.doFilter(null, null, null);
            request = new MockHttpServletRequest() {

                public String getHeader(String arg0) {
                    return "http://blaaaaaaaaah.com";
                }
            };
            response = new MockHttpServletResponse() {

                public void sendRedirect(String arg0) throws IOException {
                    assertEquals("http://kalifornia.com", arg0);
                }
            };
            instance.doFilter(request, response, null);
            request = new MockHttpServletRequest() {

                public String getHeader(String arg0) {
                    return "http://blub.com/blorb/blob/bla/blubbix";
                }
            };
            chain = new MockFilterChain() {

                /**
                 * @see com.eaio.j2ee.MockFilterChain#doFilter(javax.servlet.ServletRequest, javax.servlet.ServletResponse)
                 */
                public void doFilter(ServletRequest arg0, ServletResponse arg1)
                        throws ServletException, IOException {
                    assertNotNull(arg0);
                    assertNull(arg1);
                }

            };
            instance.doFilter(request, null, chain);
            long then = System.currentTimeMillis();
            for (int i = 0; i < 1000000; ++i) {
                instance.doFilter(request, null, chain);
            }
            System.out.println("Took " + (System.currentTimeMillis() - then) + " ms.");
        }
        catch (Exception ex) {
            ex.printStackTrace();
            fail(ex.toString());
        }

    }
}
